FIPMultipleIconPicker class

Inheritance

Constructors

FIPMultipleIconPicker({Key? key, required FIPIconController iconController, required List<IconPack>? iconPack, required double? iconSize, required String? noResultsText, required Color? backgroundColor, Color? selectedIconBackgroundColor, double? mainAxisSpacing, double? crossAxisSpacing, Color? iconColor, bool? showTooltips, Map<String, IconPickerIcon>? customIconPack})
const

Properties

backgroundColor → Color?
final
crossAxisSpacing → double?
final
customIconPack → Map<String, IconPickerIcon>?
final
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
final
iconController → FIPIconController
final
iconPack → List<IconPack>?
final
iconSize → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisSpacing → double?
final
noResultsText → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIconBackgroundColor → Color?
final
showTooltips → bool?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FIPMultipleIconPickerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited